<?php

namespace app\admin\controller;

use think\facade\Db;
use think\facade\Validate;


//公司平台分类毛利
class SupplierPlatformCatProfit extends Base
{

    //列表
    public function getList()
    {
        $param = $this->request->only(['page' => 1, 'size' => 10, 'supplier_name' => '', 'supplierNo' => '', 'platform_name' => '', 'cat_name' => ''], 'post', 'trim');

        $where = [['a.is_del', '=', 0]];
        if ($param['supplier_name'] != '') $where[] = ['b.name', 'like', '%' . $param['supplier_name'] . '%'];
        if ($param['supplierNo'] != '') $where[] = ['a.supplierNo', '=', $param['supplierNo']];
        if ($param['platform_name'] != '') $where[] = ['d.platform_name', 'like', '%' . $param['platform_name'] . '%'];
        if ($param['cat_name'] != '') $where[] = ['f.cat_name', 'like', '%' . $param['cat_name'] . '%'];

        $count = Db::name('supplier_platform_cat_profit')
            ->alias('a')
            ->leftJoin('supplier b', 'b.code=a.supplierNo')
            ->leftJoin('supplier_platform c', 'c.id=a.supplier_platform_id AND c.is_del=0')
            ->leftJoin('platform d', 'd.id=c.platform_id AND d.is_del=0')
            ->leftJoin('supplier_cat e', 'e.id=a.supplier_cat_id AND e.is_del=0')
            ->leftJoin('cat f', 'f.id=e.cat_id AND f.is_del=0')
            ->where($where)
            ->count('a.id');

        $list = Db::name('supplier_platform_cat_profit')
            ->alias('a')
            ->field('a.id,a.supplierNo,a.rate,a.order_rate,a.money_rate,a.low_rate,a.sale_rate,a.lower_rate,a.status,a.addtime,b.name supplier_name,d.platform_name,f.cat_name')
            ->leftJoin('supplier b', 'b.code=a.supplierNo')
            ->leftJoin('supplier_platform c', 'c.id=a.supplier_platform_id AND c.is_del=0')
            ->leftJoin('platform d', 'd.id=c.platform_id AND d.is_del=0')
            ->leftJoin('supplier_cat e', 'e.id=a.supplier_cat_id AND e.is_del=0')
            ->leftJoin('cat f', 'f.id=e.cat_id AND f.is_del=0')
            ->where($where)
            ->order('a.id', 'desc')
            ->page($param['page'], $param['size'])
            ->select()
            ->toArray();

        return json_show(0, '获取列表成功', ['count' => $count, 'list' => $list]);
    }

    //添加
    public function add()
    {
        $param = $this->request->only(['supplierNo', 'supplier_platform_id', 'supplier_cat_id', 'rate', 'order_rate', 'money_rate', 'low_rate', 'sale_rate', 'lower_rate'], 'post', 'trim');

        $val = Validate::rule([
            'supplierNo|公司编码' => 'require|length:18',
            'supplier_platform_id|公司平台id' => 'require|number|gt:0',
            'supplier_cat_id|公司分类id' => 'require|number|gt:0',
            'rate|主管利率' => 'require|number|between:0,100',
            'order_rate|预算成本' => 'require|number|between:0,100',
            'money_rate|财务利率' => 'require|number|between:0,100',
            'low_rate|最低利率' => 'require|number|between:0,100',
            'sale_rate|成本售价' => 'require|number|between:0,100',
            'lower_rate|BOSS利率' => 'require|number|between:0,100',
        ]);

        if (!$val->check($param)) return json_show(1004, $val->getError());

        $tmp_sp = Db::name('supplier_platform')
            ->field('id,status')
            ->where(['is_del' => 0, 'supplierNo' => $param['supplierNo'], 'id' => $param['supplier_platform_id']])
            ->findOrEmpty();
        if (empty($tmp_sp)) return json_show(1004, '该公司平台不存在');
        if ($tmp_sp['status'] == 0) return json_show(1004, '该公司平台已禁用');

        $tmp_sc = Db::name('supplier_cat')
            ->field('id,status')
            ->where(['is_del' => 0, 'supplierNo' => $param['supplierNo'], 'id' => $param['supplier_cat_id']])
            ->findOrEmpty();
        if (empty($tmp_sc)) return json_show(1004, '该公司分类不存在');
        if ($tmp_sc['status'] == 0) return json_show(1004, '该公司分类已禁用');

        $tmp_spcp = Db::name('supplier_platform_cat_profit')
            ->field('id')
            ->where(['is_del' => 0, 'supplierNo' => $param['supplierNo'], 'supplier_platform_id' => $param['supplier_platform_id'], 'supplier_cat_id' => $param['supplier_cat_id']])
            ->findOrEmpty();
        if (!empty($tmp_spcp)) return json_show(1004, '该公司平台分类的毛利已存在');

        $rs = Db::name('supplier_platform_cat_profit')
            ->insert([
                'supplierNo' => $param['supplierNo'],
                'supplier_platform_id' => $param['supplier_platform_id'],
                'supplier_cat_id' => $param['supplier_cat_id'],
                'rate' => $param['rate'],
                'order_rate' => $param['order_rate'],
                'money_rate' => $param['money_rate'],
                'low_rate' => $param['low_rate'],
                'sale_rate' => $param['sale_rate'],
                'lower_rate' => $param['lower_rate'],
                'status' => 1,
                'is_del' => 0,
                'addtime' => date('Y-m-d H:i:s'),
                'updatetime' => date('Y-m-d H:i:s'),
            ]);

        return $rs ? json_show(0, '添加成功') : json_show(1004, '添加失败');
    }

    //详情
    public function info()
    {
        $id = $this->request->post('id/d', 0, 'trim');

        $rs = Db::name('supplier_platform_cat_profit')
            ->field(true)
            ->where(['id' => $id, 'is_del' => 0])
            ->findOrEmpty();
        return json_show(0, '获取详情成功', $rs);
    }

    //修改
    public function update()
    {
        $param = $this->request->only(['id', 'rate', 'order_rate', 'money_rate', 'low_rate', 'sale_rate', 'lower_rate'], 'post', 'trim');

        $val = Validate::rule([
            'id' => 'require|number|gt:0',
            'rate|主管利率' => 'require|number|between:0,100',
            'order_rate|预算成本' => 'require|number|between:0,100',
            'money_rate|财务利率' => 'require|number|between:0,100',
            'low_rate|最低利率' => 'require|number|between:0,100',
            'sale_rate|成本售价' => 'require|number|between:0,100',
            'lower_rate|BOSS利率' => 'require|number|between:0,100',
        ]);

        if (!$val->check($param)) return json_show(1004, $val->getError());

        $rs = Db::name('supplier_platform_cat_profit')
            ->field('id')
            ->where(['is_del' => 0, 'id' => $param['id']])
            ->findOrEmpty();

        if (empty($rs)) return json_show(1004, '该记录不存在');


        $rs = Db::name('supplier_platform_cat_profit')
            ->where(['is_del' => 0, 'id' => $param['id']])
            ->update([
                'rate' => $param['rate'],
                'order_rate' => $param['order_rate'],
                'money_rate' => $param['money_rate'],
                'low_rate' => $param['low_rate'],
                'sale_rate' => $param['sale_rate'],
                'lower_rate' => $param['lower_rate'],
                'updatetime' => date('Y-m-d H:i:s')
            ]);

        return $rs ? json_show(0, '修改成功') : json_show(1004, '修改失败');
    }

    //启禁用
    public function status()
    {
        $param = $this->request->only(['id', 'status'], 'post', 'trim');

        $val = Validate::rule([
            'id' => 'require|number|gt:0',
            'status|状态' => 'require|number|in:0,1',
        ]);

        if (!$val->check($param)) return json_show(1004, $val->getError());

        $tmp = Db::name('supplier_platform_cat_profit')
            ->field('id,status')
            ->where(['is_del' => 0, 'id' => $param['id']])
            ->findOrEmpty();

        if (empty($tmp)) return json_show(1004, '该记录不存在');
        if ($tmp['status'] == $param['status']) return json_show(1004, '重复操作');

        $rs = Db::name('supplier_platform_cat_profit')
            ->where(['is_del' => 0, 'id' => $param['id']])
            ->where('status', '<>', $param['status'])
            ->update([
                'status' => $param['status'],
                'updatetime' => date('Y-m-d H:i:s')
            ]);

        return $rs ? json_show(0, '操作成功') : json_show(1004, '操作失败');
    }

    //删除
    public function delete()
    {
        $id = $this->request->post('id/d', 0, 'trim');

        $rs = Db::name('supplier_platform_cat_profit')
            ->where(['is_del' => 0, 'id' => $id])
            ->update([
                'is_del' => 1,
                'updatetime' => date('Y-m-d H:i:s')
            ]);

        return $rs ? json_show(0, '删除成功') : json_show(1004, '删除失败');
    }

}